==> sagcad_0.9.6.orig.tar.gz: sagcad-0.9.6/src/InputBox.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : InputBox.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2001/01/30
 *    Last                 : 2002/06/25
 * ============================================================
 */


#ifndef __INPUTBOX_H__
#define __INPUTBOX_H__

//#include <>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 :   (struct #define etc)
 * -------------------------------------------------------
 */

typedef struct {
    int value;
    char str[256];
    GtkWidget *dialog;
}input_box;



/* -------------------------------------------------------
 * 2 : ѿ
 * -------------------------------------------------------
 */
/* --- < InputBox.c ƤФ줿Ȥ > --------------------- */
#ifdef INPUTBOX 
	char BeforeStr[256];


/* --- < InputBox.c ʳƤФ줿Ȥ > ----------------- */
#else 
	extern char BeforeStr[256];



#endif /* INPUTBOX */
#undef INPUTBOX


/* -------------------------------------------------------
 * 3 : ؿ
 * -------------------------------------------------------
 */
int InputBox(const char *title, const char *msg1, const char *msg2, char *def_str);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __INPUTBOX_H__ */



/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : InputBox.h
 * ============================================================
 */

==> sagcad-0.9.11.tar.gz: sagcad-0.9.11/src/InputBox.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : InputBox.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2001/01/30
 *    Last                 : 2007/10/24
 * ============================================================
 */


#ifndef __INPUTBOX_H__
#define __INPUTBOX_H__

//#include <>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 : 前処理  (struct #define etc)
 * -------------------------------------------------------
 */

typedef struct {
    int value;
    char str[256];
    GtkWidget *dialog;
    GtkWidget *entry;
}input_box;



/* -------------------------------------------------------
 * 2 : 外部変数
 * -------------------------------------------------------
 */
/* --- < InputBox.c から呼ばれたとき > --------------------- */
#ifdef INPUTBOX 
	char BeforeStr[256];


/* --- < InputBox.c 以外から呼ばれたとき > ----------------- */
#else 
	extern char BeforeStr[256];



#endif /* INPUTBOX */
#undef INPUTBOX


/* -------------------------------------------------------
 * 3 : 外部関数
 * -------------------------------------------------------
 */
int InputBox(const char *title, const char *msg1, const char *msg2, char *def_str);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __INPUTBOX_H__ */



/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : InputBox.h
 * ============================================================
 */
